import * as React from "react";
import { useEffect } from "react";
import { ConfigProvider } from "antd";
import { DndProvider } from "react-dnd";
import moment from "moment";
import { Provider } from "mobx-react";
import zhCN from "antd/lib/locale/zh_CN";
import { HTML5Backend } from "react-dnd-html5-backend";
// @ts-ignore
import { connect, IRouteComponentProps, useModel } from "umi";
// import BaseLayout from "./BaseLayout";
import BlankLayout from "./BlankLayout";
import HiPrintLayout from "./HiPrintLayout";
// import UserLayout from "./UserLayout";
import PageEmptyLayout from "./PageEmptyLayout";
import { IRouterProps, RouterContext } from "./RouterContext";
import { layoutConfig } from "@/layouts/config";
import stores from "@/store";
import { Storage } from "@/utils";
import "moment/locale/zh-cn";
import "antd/dist/antd.variable.min.css";

moment.locale("zh-cn");

const Layout = ({ children, location, route, history, match }: IRouteComponentProps) => {
  const props = { children, location, route, history, match };
  const { query } = location;
  const embed = {
    hideHead: !!(query.hideHead && query.hideHead === "true"),
    hideSide: !!(query.hideSide && query.hideSide === "true"),
    hideFoot: !!(query.hideFoot && query.hideFoot === "true"),
    hideAll: !!(query.hideAll && query.hideAll === "true")
  };
  const masterProps = useModel("@@qiankunStateFromMaster");
  let containerStyle: React.CSSProperties = {};
  if (masterProps?.hideAll) {
    embed.hideAll = true;
    containerStyle = masterProps?.containerStyle || {};
  }

  const routerProps: IRouterProps = { ...embed };

  useEffect(() => {
    // API.SettingService.initSystemParam();
    const { themeFontSize } = Storage.local.get("theme-themeInfo") || { themeFontSize: "12" };
    document.documentElement.style.setProperty("--data-size", themeFontSize + "px");
    const checkData = () => {
      const { themeFontSize } = Storage.local.get("theme-themeInfo") || { themeFontSize: "12" };
      document.documentElement.style.setProperty("--data-size", themeFontSize + "px");
    };
    window.addEventListener("storage", checkData);
    return () => {
      window.removeEventListener("storage", checkData);
    };
  }, []);

  let layout;
  if (embed.hideAll) {
    layout = <BlankLayout {...props} style={containerStyle} />;
  } else {
    let { pathname } = location;
    pathname = pathname.startsWith("/") ? pathname : `/${pathname}`;
    let type = layoutConfig[pathname];
    if (!type) {
      type = _.find(layoutConfig, (v: any, k: any) => new RegExp(k).test(pathname));
    }

    if (type) {
      switch (type) {
        // case "user":
        //   layout = <UserLayout {...props} />;
        //   break;
        case "blank":
          layout = <BlankLayout {...props} />;
          break;
        case "hiPrint":
          layout = <HiPrintLayout {...props} />;
          break;
        default:
          layout = <PageEmptyLayout {...props} />;
          break;
      }
    } else {
      layout = <PageEmptyLayout {...props} />;
    }
  }

  return (
    <Provider {...stores}>
      <DndProvider backend={HTML5Backend}>
        <RouterContext.Provider value={routerProps}>
          <ConfigProvider locale={zhCN}>{layout}</ConfigProvider>
        </RouterContext.Provider>
      </DndProvider>
    </Provider>
  );
};

export default connect()(Layout);
