/*
 * Author: 黎永顺
 * name: 薪资核算-底部合计行
 * Description:
 * Date: 2023/9/18
 */
import React, { FunctionComponent, useCallback, useEffect, useMemo, useState } from "react";
import { Spin, Table, Typography } from "antd";
import { ColumnType } from "antd/lib/table";
import API from "@/api";

const { Text } = Typography;

interface OwnProps {
  columns: ColumnType<any>[];
  dataSourceUrl: string;
  payload: any;
  sumRow: Partial<{}>;
}

type Props = OwnProps;

const calcFixedTotal: FunctionComponent<Props> = (props) => {
  const [sumRow, setSumRow] = useState<Partial<{}>>({});//薪资核算总计行数据
  const [loading, setLoading] = useState<boolean>(false);
  const flattenFn = (source: ColumnType<any>[]) => {
    let res: ColumnType<any>[] = [];
    source.forEach((el: any) => {
      _.isEmpty(el.children) && res.push(el);
      el.children && res.push(...flattenFn(el.children));
    });
    return res;
  };
  const columns = useMemo(() => {
    return !_.isEmpty(props.columns) ? flattenFn(props.columns) : [];
  }, [props.columns]);
  const dataSourceUrl = useCallback((payload) => {
    return API.CalculateService.getAcctResultsum(props.dataSourceUrl, payload);
  }, [props.dataSourceUrl]);
  const debounceFetcher = _.debounce(() => {
    debounceFetcher && debounceFetcher.cancel();
    setLoading(true);
    dataSourceUrl(props.payload).then(({ data }) => {
      setLoading(false);
      const { data: result, status } = data;
      if (status) setSumRow(result.sumRow || {});
    });
  }, 800);
  useEffect(() => {
    if (!_.isEmpty(props.payload) && !props.sumRow) {
      (props.payload?.updateSum || _.isNil(props.payload?.updateSum)) && debounceFetcher();
    } else {
      setSumRow(props.sumRow);
    }
    return () => debounceFetcher && debounceFetcher.cancel();
  }, [props.payload, props.sumRow]);

  return (<>
    {
      _.map(columns, (item: any, index) => {
        return <Table.Summary.Cell index={index + 1} key={index + 1} align={_.head(columns)?.align || "left"}>
          {
            loading ? <Spin spinning={loading} size="small"></Spin> :
              <Text type="danger">{(sumRow && !_.isNil(sumRow[item.dataIndex])) ? sumRow[item.dataIndex] : "-"}</Text>
          }
        </Table.Summary.Cell>;
      })
    }
  </>);
};

export default calcFixedTotal;
